aboutsummaryrefslogtreecommitdiffhomepage
path: root/Eigen/src/CholmodSupport
diff options
context:
space:
mode:
authorGravatar Gael Guennebaud <g.gael@free.fr>2011-12-10 23:08:10 +0100
committerGravatar Gael Guennebaud <g.gael@free.fr>2011-12-10 23:08:10 +0100
commitf60e6f5ee8314b563c2c3053255011b64f8d6635 (patch)
tree92c4fb16a71c3405e1f60f512436e3bbdfe0088a /Eigen/src/CholmodSupport
parent594fd2d11d49fc3d84065de911ea25e88cb90d1c (diff)
s/compressed()/isCompressed()
Diffstat (limited to 'Eigen/src/CholmodSupport')
-rw-r--r--Eigen/src/CholmodSupport/CholmodSupport.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/Eigen/src/CholmodSupport/CholmodSupport.h b/Eigen/src/CholmodSupport/CholmodSupport.h
index 38f2ae3d5..c3c500faa 100644
--- a/Eigen/src/CholmodSupport/CholmodSupport.h
+++ b/Eigen/src/CholmodSupport/CholmodSupport.h
@@ -73,7 +73,7 @@ cholmod_sparse viewAsCholmod(SparseMatrix<_Scalar,_Options,_Index>& mat)
res.i = mat.innerIndexPtr();
res.x = mat.valuePtr();
res.sorted = 1;
- if(mat.compressed())
+ if(mat.isCompressed())
{
res.packed = 1;
}
@@ -170,7 +170,7 @@ enum CholmodMode {
* \tparam _UpLo the triangular part that will be used for the computations. It can be Lower
* or Upper. Default is Lower.
*
* This class supports all kind of SparseMatrix<>: row or column major; upper, lower, or both; compressed or uncompressed.
*
* \sa \ref TutorialSparseDirectSolvers
*/
@@ -170,7 +170,7 @@ enum CholmodMode {
* or Upper. Default is Lower.
*
- * This class supports all kind of SparseMatrix<>: row or column major; upper, lower, or both; compressed or uncompressed.
+ * This class supports all kind of SparseMatrix<>: row or column major; upper, lower, or both; isCompressed() or unisCompressed().
*
* \sa \ref TutorialSparseDirectSolvers